@@ -131,10 +131,7 @@ void bli_acquire_mpart_mdim
 	// partitioned through normally.) Note that the function called below
 	// assumes forward partitioning.
 	if ( bli_obj_is_panel_packed( obj ) )
-	{
-		bli_packm_acquire_mpart_t2b( req_part, i, b, obj, sub_obj );
-		return;
-	}
+		bli_check_error_code( BLIS_PACK_SCHEMA_NOT_SUPPORTED_FOR_PART );
 
 
 	// Check parameters.
@@ -354,10 +351,7 @@ void bli_acquire_mpart_ndim
 	// partitioned through normally.) Note that the function called below
 	// assumes forward partitioning.
 	if ( bli_obj_is_panel_packed( obj ) )
-	{
-		bli_packm_acquire_mpart_l2r( req_part, j, b, obj, sub_obj );
-		return;
-	}
+		bli_check_error_code( BLIS_PACK_SCHEMA_NOT_SUPPORTED_FOR_PART );
 
 
 	// Check parameters.
@@ -577,10 +571,7 @@ void bli_acquire_mpart_mndim
 	// partitioned through normally.) Note that the function called below
 	// assumes forward partitioning.
 	if ( bli_obj_is_panel_packed( obj ) )
-	{
-		bli_packm_acquire_mpart_tl2br( req_part, ij, b, obj, sub_obj );
-		return;
-	}
+		bli_check_error_code( BLIS_PACK_SCHEMA_NOT_SUPPORTED_FOR_PART );
 
 
 	// Check parameters.
